@@ -14,7 +14,7 @@ has moz => ( is => 'ro', isa => InstanceOf ['Pcore::API::Moz'], required => 1 );
 has id  => ( is => 'ro', isa => Str, required => 1 );
 has key => ( is => 'ro', isa => Str, required => 1 );
 
-has _cookie_jar => ( is => 'ro', isa => HashRef, default => sub { {} }, init_arg => undef );
+has _cookies => ( is => 'ro', isa => HashRef, default => sub { {} }, init_arg => undef );
 
 has next_req_ts => ( is => 'ro', isa => PositiveOrZeroInt, default => 0, init_arg => undef );
 
@@ -49,7 +49,7 @@ sub get_url_metrics ( $self, $domains, $metric, $cb ) {
             persistent => 0,
             proxy      => $proxy,
             useragent  => 'Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:47.0) Gecko/20100101 Firefox/47.0',
-            cookie_jar => $self->{_cookie_jar},
+            cookies    => $self->{_cookies},
             on_finish  => sub ($res) {
                 my $api_res;
 
